Learn R Programming

turkeyelections (version 0.1.4)

cb_2018_turkiye: Information for the results of the presidental election in Turkey in 2018.

Description

A dataset showing the information for the candidates competing in the presidental election, and their votes in count and percentage.

Usage

cb_2018_turkiye

Arguments

Format

A data frame with 6 rows and 3 variables:

Aday

aday adi, name of the candidate

Oy

alinan oy sayisi, the number of votes received

Yuzde

alinan oy sayisi (yuzde olarak), the percentage of votes received