show_parliament: show_result_for_turkey

View source: R/show_parliament.R

show_parliamentR Documentation

show_result_for_turkey

Description

A function that visualizes parliament with respect to election results across Turkey

Usage

show_parliament(x)

Arguments

x

The name of the data frame which is for the general election, so the name should contain genel in its name.

Value

A visual that shows the parliament for the given election result

Examples


show_parliament()


turkeyelections documentation built on May 29, 2024, 4:20 a.m.