Learn R Programming

turkeyelections (version 0.1.4)

yerel_secim_2024_il: Information for the 2024 Local Election Results in Turkey by Province A dataset showing detailed information for the overall results of the 2024 local elections, including vote counts and percentages for all major political parties across Turkish provinces.

Description

Information for the 2024 Local Election Results in Turkey by Province A dataset showing detailed information for the overall results of the 2024 local elections, including vote counts and percentages for all major political parties across Turkish provinces.

Usage

yerel_secim_2024_il

Arguments

Format

A data frame with rows representing various provinces and variables detailing the vote counts and percentages for each party:

İl Adı

il adı, the name of the province.

Kayıtlı Seçmen Sayısı

kayıtlı seçmen sayısı, the total number of registered voters.

Oy Kullanan Seçmen Sayısı

oy kullanan seçmen sayısı, the total number of voters who cast a ballot.

Geçerli Oy Toplamı

geçerli oy toplamı, the total number of valid votes.

AK PARTİ

AK PARTİ'nin oy sayısı, the total number of votes for the Justice and Development Party (AK PARTI).

İYİ PARTİ

İYİ PARTİ'nin oy sayısı, the total number of votes for the Good Party (İYİ PARTİ).

SOL PARTİ

SOL PARTİ'nin oy sayısı, the total number of votes for the Left Party (SOL PARTİ).

BÜYÜK BİRLİK

BÜYÜK BİRLİK Partisi'nin oy sayısı, the total number of votes for the Great Unity Party (BÜYÜK BİRLİK).

MEMLEKET

MEMLEKET Partisi'nin oy sayısı, the total number of votes for the Homeland Party (MEMLEKET).

ANAP

ANAP'ın oy sayısı, the total number of votes for the Motherland Party (ANAP).

DSP

DSP'nin oy sayısı, the total number of votes for the Democratic Left Party (DSP).

YENİDEN REFAH

YENİDEN REFAH Partisi'nin oy sayısı, the total number of votes for the New Welfare Party (YENİDEN REFAH).

DEM Parti

DEM Parti'nin oy sayısı, the total number of votes for the Peoples' Equality and Democracy Party (DEM Parti).

TKP

TKP'nin oy sayısı, the total number of votes for the Communist Party of Turkey (TKP).

ABP

ABP'nin oy sayısı, the total number of votes for the Anatolian Unity Party (ABP).

ZAFER PARTİSİ

ZAFER PARTİSİ'nin oy sayısı, the total number of votes for the Victory Party (ZAFER PARTİSİ).

HKP

HKP'nin oy sayısı, the total number of votes for the People's Liberation Party (HKP).

TKH

TKH'nin oy sayısı, the total number of votes for the Communist Movement of Turkey (TKH).

BTP

BTP'nin oy sayısı, the total number of votes for the Independent Turkey Party (BTP).

GELECEK PARTİSİ

GELECEK PARTİSİ'nin oy sayısı, the total number of votes for the Future Party (GELECEK PARTİSİ).

YTP

YTP'nin oy sayısı, the total number of votes for the New Turkey Party (YTP).

CHP

CHP'nin oy sayısı, the total number of votes for the Republican People's Party (CHP).

EMEP

EMEP'in oy sayısı, the total number of votes for the Labour Party (EMEP).

HÜDA PAR

HÜDA PAR'ın oy sayısı, the total number of votes for the Free Cause Party (HÜDA PAR).

HAK-PAR

HAK-PAR'ın oy sayısı, the total number of votes for the Rights and Freedoms Party (HAK-PAR).

OCAK

OCAK Partisi'nin oy sayısı, the total number of votes for the OCAK Party.

AB PARTİ

AB PARTİ'nin oy sayısı, the total number of votes for the Justice and Unity Party (AB PARTİ).

DP

DP'nin oy sayısı, the total number of votes for the Democratic Party (DP).

GBP

GBP'nin oy sayısı, the total number of votes for the Great Homeland Party (GBP).

MİLLET

MİLLET Partisi'nin oy sayısı, the total number of votes for the Nation Party (MİLLET).

MİLLİ YOL

MİLLİ YOL Partisi'nin oy sayısı, the total number of votes for the National Path Party (MİLLİ YOL).

AP

AP'nin oy sayısı, the total number of votes for the Alliance Party (AP).

ADP

ADP'nin oy sayısı, the total number of votes for the Anatolian Democratic Party (ADP).

MHP

MHP'nin oy sayısı, the total number of votes for the Nationalist Movement Party (MHP).

TİP

TİP'in oy sayısı, the total number of votes for the Workers' Party of Turkey (TİP).

DEVA PARTİSİ

DEVA PARTİSİ'nin oy sayısı, the total number of votes for the DEVA Party (DEVA PARTİSİ).

SAADET

SAADET Partisi'nin oy sayısı, the total number of votes for the Felicity Party (SAADET).

VATAN PARTİSİ

VATAN PARTİSİ'nin oy sayısı, the total number of votes for the Homeland Party (VATAN PARTİSİ).

BAĞIMSIZ TOPLAM OY

BAĞIMSIZ TOPLAM OY sayısı, the total number of votes received by independent candidates.

AK PARTİ_%

AK PARTİ'nin oy yüzdesi, the percentage of valid votes for AK PARTI.

İYİ PARTİ_%

İYİ PARTİ'nin oy yüzdesi, the percentage of valid votes for İYİ PARTİ.

SOL PARTİ_%

SOL PARTİ'nin oy yüzdesi, the percentage of valid votes for SOL PARTİ.

BÜYÜK BİRLİK_%

BÜYÜK BİRLİK'in oy yüzdesi, the percentage of valid votes for BÜYÜK BİRLİK.

MEMLEKET_%

MEMLEKET'in oy yüzdesi, the percentage of valid votes for MEMLEKET.

ANAP_%

ANAP'ın oy yüzdesi, the percentage of valid votes for ANAP.

DSP_%

DSP'nin oy yüzdesi, the percentage of valid votes for DSP.

YENİDEN REFAH_%

YENİDEN REFAH'ın oy yüzdesi, the percentage of valid votes for YENİDEN REFAH.

DEM Parti_%

DEM Parti'nin oy yüzdesi, the percentage of valid votes for DEM Parti.

TKP_%

TKP'nin oy yüzdesi, the percentage of valid votes for TKP.

ABP_%

ABP'nin oy yüzdesi, the percentage of valid votes for ABP.

ZAFER PARTİSİ_%

ZAFER PARTİSİ'nin oy yüzdesi, the percentage of valid votes for ZAFER PARTİSİ.

HKP_%

HKP'nin oy yüzdesi, the percentage of valid votes for HKP.

TKH_%

TKH'nin oy yüzdesi, the percentage of valid votes for TKH.

BTP_%

BTP'nin oy yüzdesi, the percentage of valid votes for BTP.

GELECEK PARTİSİ_%

GELECEK PARTİSİ'nin oy yüzdesi, the percentage of valid votes for GELECEK PARTİSİ.

YTP_%

YTP'nin oy yüzdesi, the percentage of valid votes for YTP.

CHP_%

CHP'nin oy yüzdesi, the percentage of valid votes for CHP.

EMEP_%

EMEP'in oy yüzdesi, the percentage of valid votes for EMEP.

HÜDA PAR_%

HÜDA PAR'ın oy yüzdesi, the percentage of valid votes for HÜDA PAR.

HAK-PAR_%

HAK-PAR'ın oy yüzdesi, the percentage of valid votes for HAK-PAR.

OCAK_%

OCAK'ın oy yüzdesi, the percentage of valid votes for OCAK.

AB PARTİ_%

AB PARTİ'nin oy yüzdesi, the percentage of valid votes for AB PARTİ.

DP_%

DP'nin oy yüzdesi, the percentage of valid votes for DP.

GBP_%

GBP'nin oy yüzdesi, the percentage of valid votes for GBP.

MİLLET_%

MİLLET'in oy yüzdesi, the percentage of valid votes for MİLLET.

MİLLİ YOL_%

MİLLİ YOL'un oy yüzdesi, the percentage of valid votes for MİLLİ YOL.

AP_%

AP'nin oy yüzdesi, the percentage of valid votes for AP.

ADP_%

ADP'nin oy yüzdesi, the percentage of valid votes for ADP.

MHP_%

MHP'nin oy yüzdesi, the percentage of valid votes for MHP.

TİP_%

TİP'in oy yüzdesi, the percentage of valid votes for TİP.

DEVA PARTİSİ_%

DEVA PARTİSİ'nin oy yüzdesi, the percentage of valid votes for DEVA PARTİSİ.

SAADET_%

SAADET'in oy yüzdesi, the percentage of valid votes for SAADET.

VATAN PARTİSİ_%

VATAN PARTİSİ'nin oy yüzdesi, the percentage of valid votes for VATAN PARTİSİ.

BAĞIMSIZ TOPLAM OY_%

BAĞIMSIZ TOPLAM OY'un oy yüzdesi, the total percentage of valid votes received by independent candidates.