Learn R Programming

turkeyelections (version 0.1.4)

yerel_secim_2024_turkiye: Information for the overall results of the 2024 Local Elections in Turkey A dataset showing the total number of votes and the number of mayoral positions (Metropolitan, District, and Town) won by each political party nationwide in the 2024 Local Elections.

Description

Information for the overall results of the 2024 Local Elections in Turkey A dataset showing the total number of votes and the number of mayoral positions (Metropolitan, District, and Town) won by each political party nationwide in the 2024 Local Elections.

Usage

yerel_secim_2024_turkiye

Arguments

Format

A data frame with rows for each political party and 9 variables:

Parti

parti, the standardized name of the political party.

Genel_baskani

genel başkanı, the general chairperson/leader of the political party at the time of the election.

Ittifak

ittifak, the political alliance the party participated in (if any).

Belde

belde, the number of mayoral positions won in towns (Belde) nationwide.

İlçe

ilçe, the number of mayoral positions won in districts (İlçe) nationwide.

Büyükşehir

büyükşehir, the number of mayoral positions won in metropolitan municipalities (Büyükşehir) nationwide.

Toplam

toplam, the total number of mayoral positions won across all three categories (Belde + İlçe + Büyükşehir).

Oy

oy, the total number of votes received by the party nationwide.

Yuzde

yüzde, the percentage of total votes received by the party nationwide.