View source: R/show_parliament.R
| show_parliament | R Documentation |
A function that visualizes parliament with respect to election results across Turkey
show_parliament(x)
x |
The name of the data frame which is for the general election, so the name should contain genel in its name. |
A visual that shows the parliament for the given election result
show_parliament()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.