Learn R Programming

turkeyelections (version 0.1.4)

show_parliament: show_result_for_turkey

Description

A function that visualizes parliament with respect to election results across Turkey

Usage

show_parliament(x)

Value

A visual that shows the parliament for the given election result

Arguments

x

The name of the data frame which is for the general election, so the name should contain genel in its name.

Examples

Run this code
# \donttest{
# Data example
genel_election_data <- data.frame(
  Parti = c("AKP", "CHP", "MHP", "IYI", "HDP"),
  Sandalye = c(290, 150, 50, 40, 60),
  stringsAsFactors = FALSE
)
show_parliament(genel_election_data)
# }

Run the code above in your browser using DataLab