A function that displays the election results of a specified political party in a given province, both as percentages and as absolute figures, in the form of a graph.
Usage
show_province_and_party(province = "Ankara", party = "CHP", percentage = FALSE)
Value
A visual that shows the election results of a specified political party in a given province
Arguments
province
The name of the province that users want to look for
party
The name of the political party that users want to look for
percentage
It is a boolean argument which allows you to print the plot with the percentage or not