powered by
A function that visualizes election results across Turkey, with the option to display the results either as percentages or as absolute numbers.
show_result_for_turkey(x, percentage = FALSE)
A visual that shows the percentages for each parties for the given election result
the name of the data frame to be visualized. It is supposeed to be the one including name turkey in the file name.
It is a boolean argument which allows you to print the plot with the percentage or not
# \donttest{ show_result_for_turkey() # }
Run the code above in your browser using DataLab