Information for the 2024 Local Election Results in Turkey by Province A dataset showing detailed information for the overall results of the 2024 local elections, including vote counts and percentages for all major political parties across Turkish provinces.
yerel_secim_2024_ilA data frame with rows representing various provinces and variables detailing the vote counts and percentages for each party:
il adı, the name of the province.
kayıtlı seçmen sayısı, the total number of registered voters.
oy kullanan seçmen sayısı, the total number of voters who cast a ballot.
geçerli oy toplamı, the total number of valid votes.
AK PARTİ'nin oy sayısı, the total number of votes for the Justice and Development Party (AK PARTI).
İYİ PARTİ'nin oy sayısı, the total number of votes for the Good Party (İYİ PARTİ).
SOL PARTİ'nin oy sayısı, the total number of votes for the Left Party (SOL PARTİ).
BÜYÜK BİRLİK Partisi'nin oy sayısı, the total number of votes for the Great Unity Party (BÜYÜK BİRLİK).
MEMLEKET Partisi'nin oy sayısı, the total number of votes for the Homeland Party (MEMLEKET).
ANAP'ın oy sayısı, the total number of votes for the Motherland Party (ANAP).
DSP'nin oy sayısı, the total number of votes for the Democratic Left Party (DSP).
YENİDEN REFAH Partisi'nin oy sayısı, the total number of votes for the New Welfare Party (YENİDEN REFAH).
DEM Parti'nin oy sayısı, the total number of votes for the Peoples' Equality and Democracy Party (DEM Parti).
TKP'nin oy sayısı, the total number of votes for the Communist Party of Turkey (TKP).
ABP'nin oy sayısı, the total number of votes for the Anatolian Unity Party (ABP).
ZAFER PARTİSİ'nin oy sayısı, the total number of votes for the Victory Party (ZAFER PARTİSİ).
HKP'nin oy sayısı, the total number of votes for the People's Liberation Party (HKP).
TKH'nin oy sayısı, the total number of votes for the Communist Movement of Turkey (TKH).
BTP'nin oy sayısı, the total number of votes for the Independent Turkey Party (BTP).
GELECEK PARTİSİ'nin oy sayısı, the total number of votes for the Future Party (GELECEK PARTİSİ).
YTP'nin oy sayısı, the total number of votes for the New Turkey Party (YTP).
CHP'nin oy sayısı, the total number of votes for the Republican People's Party (CHP).
EMEP'in oy sayısı, the total number of votes for the Labour Party (EMEP).
HÜDA PAR'ın oy sayısı, the total number of votes for the Free Cause Party (HÜDA PAR).
HAK-PAR'ın oy sayısı, the total number of votes for the Rights and Freedoms Party (HAK-PAR).
OCAK Partisi'nin oy sayısı, the total number of votes for the OCAK Party.
AB PARTİ'nin oy sayısı, the total number of votes for the Justice and Unity Party (AB PARTİ).
DP'nin oy sayısı, the total number of votes for the Democratic Party (DP).
GBP'nin oy sayısı, the total number of votes for the Great Homeland Party (GBP).
MİLLET Partisi'nin oy sayısı, the total number of votes for the Nation Party (MİLLET).
MİLLİ YOL Partisi'nin oy sayısı, the total number of votes for the National Path Party (MİLLİ YOL).
AP'nin oy sayısı, the total number of votes for the Alliance Party (AP).
ADP'nin oy sayısı, the total number of votes for the Anatolian Democratic Party (ADP).
MHP'nin oy sayısı, the total number of votes for the Nationalist Movement Party (MHP).
TİP'in oy sayısı, the total number of votes for the Workers' Party of Turkey (TİP).
DEVA PARTİSİ'nin oy sayısı, the total number of votes for the DEVA Party (DEVA PARTİSİ).
SAADET Partisi'nin oy sayısı, the total number of votes for the Felicity Party (SAADET).
VATAN PARTİSİ'nin oy sayısı, the total number of votes for the Homeland Party (VATAN PARTİSİ).
BAĞIMSIZ TOPLAM OY sayısı, the total number of votes received by independent candidates.
AK PARTİ'nin oy yüzdesi, the percentage of valid votes for AK PARTI.
İYİ PARTİ'nin oy yüzdesi, the percentage of valid votes for İYİ PARTİ.
SOL PARTİ'nin oy yüzdesi, the percentage of valid votes for SOL PARTİ.
BÜYÜK BİRLİK'in oy yüzdesi, the percentage of valid votes for BÜYÜK BİRLİK.
MEMLEKET'in oy yüzdesi, the percentage of valid votes for MEMLEKET.
ANAP'ın oy yüzdesi, the percentage of valid votes for ANAP.
DSP'nin oy yüzdesi, the percentage of valid votes for DSP.
YENİDEN REFAH'ın oy yüzdesi, the percentage of valid votes for YENİDEN REFAH.
DEM Parti'nin oy yüzdesi, the percentage of valid votes for DEM Parti.
TKP'nin oy yüzdesi, the percentage of valid votes for TKP.
ABP'nin oy yüzdesi, the percentage of valid votes for ABP.
ZAFER PARTİSİ'nin oy yüzdesi, the percentage of valid votes for ZAFER PARTİSİ.
HKP'nin oy yüzdesi, the percentage of valid votes for HKP.
TKH'nin oy yüzdesi, the percentage of valid votes for TKH.
BTP'nin oy yüzdesi, the percentage of valid votes for BTP.
GELECEK PARTİSİ'nin oy yüzdesi, the percentage of valid votes for GELECEK PARTİSİ.
YTP'nin oy yüzdesi, the percentage of valid votes for YTP.
CHP'nin oy yüzdesi, the percentage of valid votes for CHP.
EMEP'in oy yüzdesi, the percentage of valid votes for EMEP.
HÜDA PAR'ın oy yüzdesi, the percentage of valid votes for HÜDA PAR.
HAK-PAR'ın oy yüzdesi, the percentage of valid votes for HAK-PAR.
OCAK'ın oy yüzdesi, the percentage of valid votes for OCAK.
AB PARTİ'nin oy yüzdesi, the percentage of valid votes for AB PARTİ.
DP'nin oy yüzdesi, the percentage of valid votes for DP.
GBP'nin oy yüzdesi, the percentage of valid votes for GBP.
MİLLET'in oy yüzdesi, the percentage of valid votes for MİLLET.
MİLLİ YOL'un oy yüzdesi, the percentage of valid votes for MİLLİ YOL.
AP'nin oy yüzdesi, the percentage of valid votes for AP.
ADP'nin oy yüzdesi, the percentage of valid votes for ADP.
MHP'nin oy yüzdesi, the percentage of valid votes for MHP.
TİP'in oy yüzdesi, the percentage of valid votes for TİP.
DEVA PARTİSİ'nin oy yüzdesi, the percentage of valid votes for DEVA PARTİSİ.
SAADET'in oy yüzdesi, the percentage of valid votes for SAADET.
VATAN PARTİSİ'nin oy yüzdesi, the percentage of valid votes for VATAN PARTİSİ.
BAĞIMSIZ TOPLAM OY'un oy yüzdesi, the total percentage of valid votes received by independent candidates.